@@ -1,7 +1,9 @@
 from sqlalchemy.dialects.postgresql import JSONB
+from flask_user import current_user
 
 from opencve.extensions import db
 from opencve.models import BaseModel
+from opencve.models.tags import CveTag, UserTag
 
 
 class Cve(BaseModel):
@@ -16,7 +18,7 @@ class Cve(BaseModel):
         index=True,
     )
 
-    cve_id = db.Column(db.String(), nullable=False, index=True)
+    cve_id = db.Column(db.String(), nullable=False)
     json = db.Column(JSONB)
 
     # We used initially secondary relationships to fetch the list of
@@ -42,11 +44,49 @@ class Cve(BaseModel):
     __table_args__ = (
         db.Index("ix_cves_vendors", vendors, postgresql_using="gin"),
         db.Index("ix_cves_cwes", cwes, postgresql_using="gin"),
+        db.Index(
+            "ix_cves_summary",
+            summary,
+            postgresql_using="gin",
+            postgresql_ops={
+                "summary": "gin_trgm_ops",
+            },
+        ),
+        db.Index(
+            "ix_cves_cve_id",
+            cve_id,
+            postgresql_using="gin",
+            postgresql_ops={
+                "cve_id": "gin_trgm_ops",
+            },
+        ),
     )
 
     def __repr__(self):
         return "<Cve {}>".format(self.cve_id)
 
+    @property
+    def raw_tags(self):
+        if not current_user.is_authenticated:
+            return []
+
+        cve_tag = CveTag.query.filter_by(
+            user_id=current_user.id, cve_id=self.id
+        ).first()
+        if not cve_tag:
+            return []
+
+        return cve_tag.tags
+
+    @property
+    def tags(self):
+        if not current_user.is_authenticated:
+            return []
+        return [
+            UserTag.query.filter_by(user_id=current_user.id, name=t).first()
+            for t in self.raw_tags
+        ]
+
     @property
     def cvss_weight(self):
         """Only used to sort several CVE by their CVSS"""
