@@ -1,5 +1,6 @@
 from sqlalchemy_utils import UUIDType
 
+from opencve.context import _humanize_filter
 from opencve.extensions import db
 from opencve.models import BaseModel, users_products
 
@@ -14,5 +15,9 @@ class Product(BaseModel):
     vendor = db.relationship("Vendor", back_populates="products")
     users = db.relationship("User", secondary=users_products)
 
+    @property
+    def human_name(self):
+        return _humanize_filter(self.name)
+
     def __repr__(self):
         return "<Product {}>".format(self.name)
